@@ -2,5 +2,5 @@ import pytest
 
 
 def test_import_bdist_wheel() -> None:
-    with pytest.warns(DeprecationWarning, match="module has been removed"):
+    with pytest.warns(FutureWarning, match="no longer the canonical location"):
         from wheel.bdist_wheel import bdist_wheel  # noqa: F401
